@@ -455,9 +455,36 @@ SQLFreeStmt(HSTMT StatementHandle,
 			SQLUSMALLINT Option)
 {
 	RETCODE	ret;
+	StatementClass *stmt = (StatementClass *) StatementHandle;
+	ConnectionClass *conn = NULL;
 
 	mylog("[SQLFreeStmt]");
+
+	if (stmt)
+	{
+		if (Option == SQL_DROP)
+		{
+			conn = stmt->hdbc;
+			if (conn)
+				ENTER_CONN_CS(conn);
+		}
+		else
+			ENTER_STMT_CS(stmt);
+	}
+
 	ret = PGAPI_FreeStmt(StatementHandle, Option);
+
+	if (stmt)
+	{
+		if (Option == SQL_DROP)
+		{
+			if (conn)
+				LEAVE_CONN_CS(conn);
+		}
+		else
+			LEAVE_STMT_CS(stmt);
+	}
+
 	return ret;
 }
 
