@@ -294,8 +294,6 @@ BOOL isMsAccess();
 BOOL isMsQuery();
 BOOL isSqlServr();
 
-#define	NULL_CATALOG_NAME				""
-
 /* ESCAPEs */
 #define	ESCAPE_IN_LITERAL				'\\'
 #define	BYTEA_ESCAPE_CHAR				'\\'
@@ -355,14 +353,10 @@ BOOL isSqlServr();
 
 /*	These prefixes denote system tables */
 #define POSTGRES_SYS_PREFIX			"pg_"
-#define KEYS_TABLE					"dd_fkey"
 
 /*	Info limits */
 #define MAX_INFO_STRING				128
-#define MAX_KEYPARTS				20
-#define MAX_KEYLEN				512 	/* max key of the form
 
-										 * "date+outlet+invoice" */
 /* POSIX defines a PATH_MAX.( wondows is _MAX_PATH ..) */
 #ifndef PATH_MAX
 #ifdef _MAX_PATH
@@ -372,15 +366,6 @@ BOOL isSqlServr();
 #endif /* _MAX_PATH */
 #endif /* PATH_MAX */
 
-#define MAX_ROW_SIZE				0	/* Unlimited rowsize with the
-										 * Tuple Toaster */
-#define MAX_STATEMENT_LEN			0	/* Unlimited statement size with
-										 * 7.0 */
-
-/* Previously, numerous query strings were defined of length MAX_STATEMENT_LEN */
-/* Now that's 0, lets use this instead. DJP 24-1-2001 */
-#define STD_STATEMENT_LEN			MAX_MESSAGE_LEN
-
 #define PG62						"6.2"		/* "Protocol" key setting
 												 * to force Postgres 6.2 */
 #define PG63						"6.3"		/* "Protocol" key setting
@@ -389,8 +374,6 @@ BOOL isSqlServr();
 #define PG74REJECTED					"reject7.4"
 #define PG74						"7.4"
 
-typedef int	(*PQFUNC)();
-
 typedef struct ConnectionClass_ ConnectionClass;
 typedef struct StatementClass_ StatementClass;
 typedef struct QResultClass_ QResultClass;
