@@ -14,6 +14,7 @@
  */
 
 #include  "psqlodbc.h"
+#include  "misc.h" // strncpy_null
 
 #include  "environ.h"
 #include  "connection.h"
@@ -275,7 +276,7 @@ ConfigDlgProc(HWND hdlg,
 			 */
 			/* override settings in ODBC.INI */
 
-			memcpy(&ci->drivers, &globals, sizeof(globals));
+			copy_globals(&ci->drivers, &globals);
 			/* Get the rest of the common attributes */
 			getDSNinfo(ci, CONN_DONT_OVERWRITE);
 
@@ -367,7 +368,7 @@ ConfigDlgProc(HWND hdlg,
 							int errnum;
 
 							EN_add_connection(env, conn);
-							memcpy(&conn->connInfo, &lpsetupdlg->ci, sizeof(ConnInfo));
+							CC_copy_conninfo(&conn->connInfo, &lpsetupdlg->ci);
 							CC_initialize_pg_version(conn);
 							logs_on_off(1, conn->connInfo.drivers.debug, conn->connInfo.drivers.commlog);
 #ifdef	UNICODE_SUPPORT
@@ -391,7 +392,7 @@ ConfigDlgProc(HWND hdlg,
 #ifdef	UNICODE_SUPPORT
 							tlen = strlen(emsg);
 							wermsg = (SQLWCHAR *) malloc(sizeof(SQLWCHAR) * (tlen + 1));
-							ulen = utf8_to_ucs2_lf1(emsg, SQL_NTS, FALSE, wermsg, tlen + 1);
+							ulen = utf8_to_ucs2_lf(emsg, SQL_NTS, FALSE, wermsg, tlen + 1, TRUE);
 							if (ulen != (SQLULEN) -1)
 							{
 								allocstr = malloc(4 * tlen + 1);
@@ -469,7 +470,7 @@ ParseAttributes(LPCSTR lpszAttributes, LPSETUPDLG lpsetupdlg)
 	int			cbKey;
 	char		value[MAXPGPATH];
 
-	CC_conninfo_init(&(lpsetupdlg->ci));
+	CC_conninfo_init(&(lpsetupdlg->ci), COPY_GLOBALS);
 
 	for (lpsz = lpszAttributes; *lpsz; lpsz++)
 	{
